@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2015 Hive Solutions Lda.
+# Copyright (c) 2008-2016 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -28,7 +28,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2015 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2016 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -45,6 +45,7 @@ from . import data
 from . import defines
 from . import exceptions
 from . import export
+from . import geo
 from . import git
 from . import http
 from . import legacy
@@ -79,9 +80,10 @@ from .data import DataAdapter, MongoAdapter, Collection, MongoCollection
 from .defines import ITERABLES, MOBILE_REGEX, MOBILE_PREFIX_REGEX, BODY_REGEX, TAG_REGEX,\
     EMAIL_REGEX, WINDOWS_LOCALE
 from .exceptions import AppierException, OperationalError, SecurityError, ValidationError,\
-    NotFoundError, NotImplementedError, BaseInternalError, ValidationInternalError, HTTPError,\
-    APIError, APIAccessError, OAuthAccessError
+    NotFoundError, NotImplementedError, BaseInternalError, ValidationInternalError,\
+    ValidationMultipleError, HTTPError, APIError, APIAccessError, OAuthAccessError
 from .export import ExportManager, MongoEncoder
+from .geo import GeoResolver
 from .git import Git
 from .http import get, post, put, delete
 from .log import MemoryHandler, ThreadFormatter, rotating_handler, smtp_handler, in_signature
@@ -102,11 +104,11 @@ from .structures import OrderedDict
 from .typesf import Type, File, Files, ImageFile, ImageFiles, image, images, Reference,\
     reference, References, references
 from .util import is_iterable, is_mobile, email_parts, email_mime, email_name, email_base,\
-    request_json, get_object, resolve_alias, page_types, find_types, norm_object, set_object,\
-    leafs, gen_token, html_to_text, camel_to_underscore, camel_to_readable, quote, unquote,\
-    base_name, base_name_m, parse_cookie, parse_multipart, decode_params, load_form, check_login,\
-    ensure_login, private, ensure, delayed, route, error_handler, exception_handler, is_detached,\
-    sanitize, execute, FileTuple, BaseThread
+    obfuscate, request_json, get_object, resolve_alias, page_types, find_types, norm_object,\
+    set_object, leafs, gen_token, html_to_text, camel_to_underscore, camel_to_readable, quote,\
+    unquote, base_name, base_name_m, parse_cookie, parse_multipart, decode_params, load_form,\
+    check_login, ensure_login, private, ensure, delayed, route, error_handler, exception_handler,\
+    before_request, after_request, is_detached, sanitize, execute, ctx_locale, FileTuple, BaseThread
 from .validation import validate, validate_b, safe, eq, gt, gte, lt, lte, not_null, not_empty,\
     not_false, is_in, is_simple, is_email, is_url, is_regex, field_eq, field_gt, field_gte,\
     field_lt, field_lte, string_gt, string_lt, string_eq, equals, not_past, not_duplicate,\
