@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2015 Hive Solutions Lda.
+# Copyright (c) 2008-2016 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2015 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2016 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -56,6 +56,15 @@ CASTS = {
 operation associated with the various data types,
 they provide a different type of casting strategy """
 
+ENV_ENCODINGS = (
+    "utf-8",
+    sys.getdefaultencoding(),
+    sys.getfilesystemencoding()
+)
+""" The sequence of encodings that are going to
+be ued to try to decode possible byte based strings
+for the various environment variable values """
+
 CONFIGS = {}
 """ The map that contains the key value association
 for all the currently set global configurations """
@@ -127,5 +136,12 @@ def load_file(path = None, encoding = "utf-8"):
 def load_env():
     for key, value in os.environ.items():
         CONFIGS[key] = value
+        is_bytes = legacy.is_bytes(value)
+        if not is_bytes: continue
+        for encoding in ENV_ENCODINGS:
+            try: value = value.decode(encoding)
+            except UnicodeDecodeError: pass
+            else: break
+        CONFIGS[key] = value
 
 load()
