@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2015 Hive Solutions Lda.
+# Copyright (c) 2008-2016 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2015 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2016 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -60,11 +60,18 @@ class AppierException(Exception):
         self.message = kwargs.get("message", self.name)
         self.code = kwargs.get("code", 500)
         self.headers = kwargs.get("headers", None)
+        self.args = args
+        self.kwargs = kwargs
 
     def __str__(self):
+        if legacy.PYTHON_3: return self.__unicode__()
+        is_unicode = legacy.is_unicode(self.message)
+        if is_unicode: return self.message.encode("utf-8")
         return self.message
 
     def __unicode__(self):
+        is_unicode = legacy.is_unicode(self.message)
+        if not is_unicode: return self.message.decode("utf-8")
         return self.message
 
     def _name(self):
@@ -151,6 +158,17 @@ class BaseInternalError(RuntimeError):
         RuntimeError.__init__(self, message)
         self.message = message
 
+    def __str__(self):
+        if legacy.PYTHON_3: return self.__unicode__()
+        is_unicode = legacy.is_unicode(self.message)
+        if is_unicode: return self.message.encode("utf-8")
+        return self.message
+
+    def __unicode__(self):
+        is_unicode = legacy.is_unicode(self.message)
+        if not is_unicode: return self.message.decode("utf-8")
+        return self.message
+
 class ValidationInternalError(BaseInternalError):
     """
     Error raised when a validation on the model fails
@@ -166,6 +184,29 @@ class ValidationInternalError(BaseInternalError):
         BaseInternalError.__init__(self, message)
         self.name = name
 
+class ValidationMultipleError(ValidationInternalError):
+    """
+    Exception/error considered to be equivalent to the
+    validation internal error, with the exception that it
+    may handle multiple errors at the same time.
+    """
+
+    errors = []
+    """ The sequence containing the multiple errors associated
+    with the validation multiple error """
+
+    def __init__(self, name = None, message = None):
+        ValidationInternalError.__init__(self, name, message)
+        self.errors = []
+
+    def add_error(self, name, message):
+        if not self.name: self.name = name
+        if not self.message: self.message = message
+        self.errors.append((name, message))
+
+    def add_exception(self, exception):
+        self.add_error(exception.name, exception.message)
+
 class HTTPError(BaseInternalError):
     """
     Top level http error raised whenever a bad response
