@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2015 Hive Solutions Lda.
+# Copyright (c) 2008-2016 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2015 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2016 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -1668,7 +1668,7 @@ class Model(legacy.with_meta(meta.Ordered, observer.Observable)):
         # retrieves the reference to the store object to be used and
         # uses it to store the current model data
         store = self._get_store()
-        if is_new: self._id = store.insert(model); self.apply(model)
+        if is_new: self._id = store.insert(model); self.apply(model, safe_a = False)
         else: store.update({"_id" : model["_id"]}, {"$set" : _model})
 
         # calls the post save event handlers in order to be able to
@@ -1981,23 +1981,11 @@ class Field(dict):
         self.creation_counter = Field.creation_counter
         Field.creation_counter += 1
 
-class Link(dict):
+class Action(dict):
     """
-    Internal link class used to encapsulate some of the
-    internal concepts associated with a link, providing
-    an easy to use structure at runtime.
-
-    The base interface should conform with the dictionary
-    interface in order to provide backwards compatibility.
-    """
-
-    pass
-
-class Operation(dict):
-    """
-    Logical structure representing an operation, should
-    provide a simple interface for interaction with the
-    operation and inputs/outputs of it.
+    The abstract class that defines an action to be performed
+    by an end used this should be used as a placeholder for
+    the generic logic of any action.
 
     The base interface should conform with the dictionary
     interface in order to provide backwards compatibility.
@@ -2038,7 +2026,25 @@ class Operation(dict):
         # so that it may be used safely in the context
         return casted
 
-def link(name = None):
+class Link(Action):
+    """
+    Internal link class used to encapsulate some of the
+    internal concepts associated with a link, providing
+    an easy to use structure at runtime.
+    """
+
+    pass
+
+class Operation(Action):
+    """
+    Logical structure representing an operation, should
+    provide a simple interface for interaction with the
+    operation and inputs/outputs of it.
+    """
+
+    pass
+
+def link(name = None, parameters = ()):
     """
     Decorator function to be used to "annotate" the provided
     function as an link (string) that is able to change the user
@@ -2050,6 +2056,9 @@ def link(name = None):
     :type name: String
     :param name: The name of the link (in plain english) so that
     a better user experience is possible.
+    :type parameters: Tuple
+    :param parameters: The sequence containing tuples that describe
+    the various parameters to be send to the link.
     :rtype: Function
     :return: The decorator function that is going to be used to
     generated the final function to be called.
@@ -2058,7 +2067,8 @@ def link(name = None):
     def decorator(function, *args, **kwargs):
         function._link = Link(
             method = function.__name__,
-            name = name or function.__name__
+            name = name or function.__name__,
+            parameters = parameters
         )
         return function
 
@@ -2068,7 +2078,7 @@ def operation(name = None, parameters = (), level = 1):
     """
     Decorator function to be used to "annotate" the provided
     function as an operation that is able to change the current
-    entity sate and behavior.
+    entity state and behavior.
 
     Proper usage of the operation definition/decoration is context
     based and should vary based on application.
