@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2015 Hive Solutions Lda.
+# Copyright (c) 2008-2016 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2015 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2016 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -142,10 +142,7 @@ class Request(object):
         self.authorization = None
         self.data = None
         self.result = None
-        self.session = session.MockSession(
-            self,
-            address = self.address
-        )
+        self.session = session.MockSession(self)
         self.set_cookie = None
         self.args = {}
         self.cookies = {}
@@ -311,9 +308,35 @@ class Request(object):
         for name, value in headers.items():
             self.set_header(name, value)
 
+    def get_address(self, resolve = True):
+        """
+        Retrieves the client (network) address associated with the
+        correct request/connection.
+
+        In case the resolve flag is set the resolution takes a more
+        complex approach to avoid the common problems when used proxy
+        based connections (indirection in connection).
+
+        :type resolve: bool
+        :param resolve: If the complex resolution process for the
+        network address should take place.
+        :rtype: String
+        :return: The resolved client (network) address.
+        """
+
+        if not resolve: return self.address
+        return self.get_header("X-Forwarded-For", self.address)
+
     def resolve_params(self):
         self.params = self._resolve_p(self.params)
 
+    def load_base(self):
+        self.load_data()
+        self.load_form()
+        self.load_authorization()
+        self.load_headers()
+        self.load_session()
+
     def load_data(self):
         # initializes the various structures associated with the data loading
         # and/or parsing, so that the request is correctly populated
@@ -373,11 +396,6 @@ class Request(object):
         )
         self.authorization = tuple(parts)
 
-    def load_session(self):
-        self.load_cookies()
-        self.set_alias()
-        self.set_session()
-
     def load_headers(self):
         for key, value in self.environ.items():
             if not key.startswith("HTTP_"): continue
@@ -387,6 +405,15 @@ class Request(object):
             key_s = "-".join(parts)
             self.in_headers[key_s] = value
 
+    def load_session(self):
+        self.load_mock()
+        self.load_cookies()
+        self.set_alias()
+        self.set_session()
+
+    def load_mock(self):
+        self.session.address = self.get_address()
+
     def load_cookies(self):
         cookie_s = self.environ.get("HTTP_COOKIE", "")
         self.cookies = util.parse_cookie(cookie_s)
@@ -518,7 +545,7 @@ class Request(object):
         if not base: return base
         expires = time.time() + delta
         expires_d = datetime.datetime.fromtimestamp(expires)
-        expires_s = expires_d.strftime("%a, %m %b %Y %H:%M:%S GMT")
+        with util.ctx_locale(): expires_s = expires_d.strftime("%a, %m %b %Y %H:%M:%S GMT")
         set_cookie = "%s;lang=%s;path=%s;expires=%s;" % (base, lang, path, expires_s)
         return set_cookie
 
@@ -541,6 +568,11 @@ class Request(object):
     def is_success(self):
         return self.code == 200
 
+    @property
+    def location_f(self):
+        if not self.query: return self.location
+        return self.location + "?" + self.query
+
     def _resolve_p(self, params):
         secret = self.session.get("secret", None)
         if not secret: return params
