@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2015 Hive Solutions Lda.
+# Copyright (c) 2008-2016 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2015 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2016 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -94,6 +94,9 @@ class Session(object):
     def __delitem__(self, key):
         self.mark()
 
+    def __iter__(self):
+        return iter(())
+
     def __contains__(self, item):
         return False
 
@@ -131,10 +134,32 @@ class Session(object):
     def close(cls):
         pass
 
+    @classmethod
+    def empty(cls):
+        pass
+
     @classmethod
     def gc(cls):
         pass
 
+    def keys(self):
+        return ()
+
+    def iterkeys(self):
+        return self.keys()
+
+    def values(self):
+        return ()
+
+    def itervalues(self):
+        return self.values()
+
+    def items(self):
+        return ()
+
+    def iteritems(self):
+        return self.items()
+
     def start(self):
         pass
 
@@ -221,9 +246,27 @@ class DataSession(Session):
     def __delitem__(self, key):
         self.mark(); return self.data.__delitem__(key)
 
+    def __iter__(self):
+        return self.data.__iter__()
+
     def __contains__(self, item):
         return self.data.__contains__(item)
 
+    def keys(self):
+        return self.data.keys()
+
+    def values(self):
+        return self.data.values()
+
+    def items(self):
+        return self.data.items()
+
+    def sorted(self):
+        keys = self.keys()
+        keys = list(keys)
+        keys.sort()
+        return keys
+
 class MemorySession(DataSession):
 
     SESSIONS = {}
@@ -262,6 +305,10 @@ class MemorySession(DataSession):
     def all(cls):
         return cls.SESSIONS
 
+    @classmethod
+    def empty(cls):
+        cls.SESSIONS.empty()
+
 class FileSession(DataSession):
 
     SHELVE = None
@@ -320,6 +367,10 @@ class FileSession(DataSession):
         cls.SHELVE.close()
         cls.SHELVE = None
 
+    @classmethod
+    def empty(cls):
+        for sid in cls.SHELVE: del cls.SHELVE[sid]
+
     @classmethod
     def gc(cls):
         for sid in cls.SHELVE:
@@ -392,10 +443,33 @@ class RedisSession(DataSession):
     def expire(cls, sid):
         cls.REDIS.delete(sid)
 
+    @classmethod
+    def count(cls):
+        if cls.REDIS == None: cls.open()
+        sids = cls.REDIS.keys()
+        return len(sids)
+
+    @classmethod
+    def all(cls):
+        if cls.REDIS == None: cls.open()
+        sessions = dict()
+        sids = cls.REDIS.keys()
+        for sid in sids:
+            data = cls.REDIS.get(sid)
+            try: session = cls.SERIALIZER.loads(data)
+            except: continue
+            sessions[sid] = session
+        return sessions
+
     @classmethod
     def open(cls):
         cls.REDIS = redisdb.get_connection()
 
+    @classmethod
+    def empty(cls):
+        if cls.REDIS == None: cls.open()
+        cls.REDIS.flushdb()
+
     def flush(self, request = None):
         if not self.is_dirty(): return
         self.mark(dirty = False)
