@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2015 Hive Solutions Lda.
+# Copyright (c) 2008-2016 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2015 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2016 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -44,7 +44,15 @@ class Person(appier.Model):
     identifier = appier.field(
         type = int,
         index = True,
-        increment = True
+        increment = True,
+        default = True
+    )
+
+    identifier_safe = appier.field(
+        type = int,
+        index = True,
+        increment = True,
+        safe = True
     )
 
     name = appier.field()
@@ -73,7 +81,15 @@ class Cat(appier.Model):
     identifier = appier.field(
         type = int,
         index = True,
-        increment = True
+        increment = True,
+        default = True
+    )
+
+    identifier_safe = appier.field(
+        type = int,
+        index = True,
+        increment = True,
+        safe = True
     )
 
     name = appier.field()
