@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2015 Hive Solutions Lda.
+# Copyright (c) 2008-2016 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2015 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2016 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -131,11 +131,13 @@ class ModelTest(unittest.TestCase):
         person.save()
 
         self.assertEqual(person.identifier, 1)
+        self.assertEqual(person.identifier_safe, 1)
         self.assertEqual(person.name, "Name")
 
         person_m = person.map()
 
         self.assertEqual(person_m["identifier"], 1)
+        self.assertEqual(person_m["identifier_safe"], 1)
         self.assertEqual(person_m["name"], "Name")
 
         person.age = 20
@@ -147,6 +149,7 @@ class ModelTest(unittest.TestCase):
         person_m = person.map(all = True)
 
         self.assertEqual(person_m["identifier"], 1)
+        self.assertEqual(person_m["identifier_safe"], 1)
         self.assertEqual(person_m["name"], "Name")
         self.assertEqual(person_m["age"], 20)
         self.assertEqual(person_m["hidden"], "Hidden")
@@ -166,6 +169,7 @@ class ModelTest(unittest.TestCase):
         person_m = person.map(resolve = True, all = True)
 
         self.assertEqual(person_m["cats"][0]["identifier"], 1)
+        self.assertEqual(person_m["cats"][0]["identifier_safe"], 1)
         self.assertEqual(person_m["cats"][0]["name"], "NameCat")
 
         person = mock.Person.get(identifier = 1)
@@ -179,4 +183,5 @@ class ModelTest(unittest.TestCase):
         person_m = person.map(resolve = True, all = True)
 
         self.assertEqual(person_m["cats"][0]["identifier"], 1)
+        self.assertEqual(person_m["cats"][0]["identifier_safe"], 1)
         self.assertEqual(person_m["cats"][0]["name"], "NameCat")
