@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2015 Hive Solutions Lda.
+# Copyright (c) 2008-2016 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2015 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2016 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -44,9 +44,11 @@ import json
 import copy
 import uuid
 import types
+import locale
 import hashlib
 import threading
 import functools
+import contextlib
 import subprocess
 
 from . import smtp
@@ -116,10 +118,13 @@ FIND_TYPES = dict(
     find_d = to_find,
     find_i = bool,
     sort = to_sort,
-    meta = bool
+    meta = bool,
+    fields = list
 )
 """ The map associating the various find fields with
-their respective types """
+their respective types, note that in case a special
+conversion operation is required the associated value
+may represent a conversion function instead """
 
 FIND_DEFAULTS = dict(
     limit = 10
@@ -220,6 +225,12 @@ def email_base(base):
     _name, email = email_parts(base)
     return email
 
+def obfuscate(value, display_l = 3, token = "*"):
+    value_l = len(value)
+    display_l = min([value_l, display_l])
+    obfuscated = value[:display_l] + ((value_l - display_l) * token)
+    return obfuscated
+
 def request_json(request = None, encoding = "utf-8"):
     # retrieves the proper request object, either the provided
     # request or the default base request object and then in
@@ -466,7 +477,7 @@ def leafs(object):
     # to the caller method so that it may be used there
     return leafs_l
 
-def gen_token():
+def gen_token(limit = None):
     """
     Generates a random cryptographic ready token according
     to the framework specification, this is generated using
@@ -476,6 +487,9 @@ def gen_token():
     The resulting value is returned as an hexadecimal based
     string according to the standard.
 
+    :type limit: int
+    :param limit: The maximum number of characters allowed
+    for the token to be generated.
     :rtype: String
     :return: The hexadecimal based string value
     """
@@ -483,6 +497,7 @@ def gen_token():
     token_s = str(uuid.uuid4())
     token_s = token_s.encode("utf-8")
     token = hashlib.sha256(token_s).hexdigest()
+    if limit: token = token[:limit]
     return token
 
 def html_to_text(data):
@@ -815,8 +830,10 @@ def parse_multipart(data, boundary):
 
         sequence = target.get(name, [])
         sequence.append(value)
+        tuple_s = (name, sequence)
+        exists = name in target
         target[name] = sequence
-        ordered.append((name, sequence))
+        if not exists: ordered.append(tuple_s)
 
     return (post, files, ordered)
 
@@ -928,7 +945,8 @@ def ensure_login(self, function, token = None, request = None):
     is_auth = "username" in request.session
     if not is_auth: raise exceptions.AppierException(
         message = "User not authenticated",
-        code = 403
+        code = 403,
+        token = token
     )
 
     if not token: return
@@ -937,7 +955,8 @@ def ensure_login(self, function, token = None, request = None):
     tokens_s = self.session.get("tokens", [])
     if not token in tokens_s: raise exceptions.AppierException(
         message = "Not enough permissions",
-        code = 403
+        code = 403,
+        token = token
     )
 
 def private(function):
@@ -1004,16 +1023,16 @@ def route(url, method = "GET", async = False, json = False):
 
     return decorator
 
-def error_handler(code):
+def error_handler(code, json = False):
 
     def decorator(function, *args, **kwargs):
         if is_detached(function): delay(function, *args, **kwargs)
-        else: common.base().App.add_error(code, function)
+        else: common.base().App.add_error(code, function, json)
         return function
 
     def delay(function, *args, **kwargs):
         global CREATION_COUNTER
-        error = (code,)
+        error = (code, json)
         if not hasattr(function, "_errors"): function._errors = []
         function._errors.append(error)
         function.creation_counter = CREATION_COUNTER
@@ -1022,16 +1041,16 @@ def error_handler(code):
 
     return decorator
 
-def exception_handler(exception):
+def exception_handler(exception, json = False):
 
     def decorator(function, *args, **kwargs):
         if is_detached(function): delay(function, *args, **kwargs)
-        else: common.base().App.add_exception(exception, function)
+        else: common.base().App.add_exception(exception, function, json)
         return function
 
     def delay(function, *args, **kwargs):
         global CREATION_COUNTER
-        _exception = (exception,)
+        _exception = (exception, json)
         if not hasattr(function, "_exceptions"): function._exceptions = []
         function._exceptions.append(_exception)
         function.creation_counter = CREATION_COUNTER
@@ -1040,6 +1059,42 @@ def exception_handler(exception):
 
     return decorator
 
+def before_request(scope = "all"):
+
+    def decorator(function, *args, **kwargs):
+        if is_detached(function): delay(function, *args, **kwargs)
+        else: common.base().App.add_custom("before_request", function)
+        return function
+
+    def delay(function, *args, **kwargs):
+        global CREATION_COUNTER
+        _custom = ("before_request",)
+        if not hasattr(function, "_customs"): function._customs = []
+        function._customs.append(_custom)
+        function.creation_counter = CREATION_COUNTER
+        CREATION_COUNTER += 1
+        return function
+
+    return decorator
+
+def after_request(scope = "all"):
+
+    def decorator(function, *args, **kwargs):
+        if is_detached(function): delay(function, *args, **kwargs)
+        else: common.base().App.add_custom("after_request", function)
+        return function
+
+    def delay(function, *args, **kwargs):
+        global CREATION_COUNTER
+        _custom = ("after_request",)
+        if not hasattr(function, "_customs"): function._customs = []
+        function._customs.append(_custom)
+        function.creation_counter = CREATION_COUNTER
+        CREATION_COUNTER += 1
+        return function
+
+    return decorator
+
 def is_detached(function):
     """
     Verifies if the provided function value is considered to be
@@ -1107,6 +1162,13 @@ def execute(args, command = None, path = None, shell = None, encoding = None):
         code = code
     )
 
+@contextlib.contextmanager
+def ctx_locale(name = "", force = False):
+    saved = locale.setlocale(locale.LC_ALL)
+    if saved == name and not force: yield saved; return
+    try: yield locale.setlocale(locale.LC_ALL, name)
+    finally: locale.setlocale(locale.LC_ALL, saved)
+
 class FileTuple(tuple):
     """
     Tuple class (inherits from tuple) that represents
@@ -1127,6 +1189,14 @@ class FileTuple(tuple):
         try: file.write(contents)
         finally: file.close()
 
+    @property
+    def name(self):
+        return self[0]
+
+    @property
+    def mime(self):
+        return self[1]
+
 class BaseThread(threading.Thread):
     """
     The top level thread class that is meant to encapsulate
