@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2015 Hive Solutions Lda.
+# Copyright (c) 2008-2016 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2015 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2016 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -104,17 +104,26 @@ def validate(method = None, methods = [], object = None, ctx = None, build = Tru
         for name, value in request.post_s.items(): object[name] = value
         for name, value in request.params_s.items(): object[name] = value
 
+    # iterates over the complete set of methods registered for validation
+    # and runs them expecting exceptions to be raised from them, each adding
+    # new errors to the current errors stack
     for method in methods:
         try: method(object, ctx = ctx)
+        except exceptions.ValidationMultipleError as error:
+            errors.extend(error.errors)
         except exceptions.ValidationInternalError as error:
             errors.append((error.name, error.message))
 
-    errors_map = {}
+    # creates the map that will be used to store the association between the
+    # field name of the object and the validation errors associated with it
+    errors_map = dict()
     for name, message in errors:
         if not name in errors_map: errors_map[name] = []
         _errors = errors_map[name]
         _errors.append(message)
 
+    # returns both the newly created errors map that associates each of the
+    # model name with the sequence of errors and the validated object (state)
     return errors_map, object
 
 def validate_b(method = None, methods = [], object = None, build = True):
